Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(85)

Unified Diff: pkg/barback/lib/src/transformer/declaring_aggregate_transformer.dart

Issue 262173009: Add aggregate transformer types to barback. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/barback/lib/src/transformer/declaring_aggregate_transformer.dart
diff --git a/pkg/barback/lib/src/transformer/declaring_transformer.dart b/pkg/barback/lib/src/transformer/declaring_aggregate_transformer.dart
similarity index 59%
copy from pkg/barback/lib/src/transformer/declaring_transformer.dart
copy to pkg/barback/lib/src/transformer/declaring_aggregate_transformer.dart
index d9e5adcc54d61fc8d56b7b4998583344243437b7..a65722b029f660cbb17a27d7967a25b7dfdc7d1d 100644
--- a/pkg/barback/lib/src/transformer/declaring_transformer.dart
+++ b/pkg/barback/lib/src/transformer/declaring_aggregate_transformer.dart
@@ -2,27 +2,23 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library barback.transformer.declaring_transformer;
-
-import 'dart:async';
-
-import 'declaring_transform.dart';
+library barback.transformer.declaring_aggregate_transformer;
/// An interface for [Transformer]s that can cheaply figure out which assets
/// they'll emit without doing the work of actually creating those assets.
///
/// If a transformer implements this interface, that allows barback to perform
/// optimizations to make the asset graph work more smoothly.
-abstract class DeclaringTransformer {
- /// Declare which assets would be emitted for the primary input id specified
+abstract class DeclaringAggregateTransformer {
+ /// Declare which assets would be emitted for the primary input ids specified
/// by [transform].
///
/// This works a little like [Transformer.apply], with two main differences.
/// First, instead of having access to the primary input's contents, it only
/// has access to its id. Second, instead of emitting [Asset]s, it just emits
/// [AssetId]s through [transform.addOutputId].
///
/// If this does asynchronous work, it should return a [Future] that completes
/// once it's finished.
- declareOutputs(DeclaringTransform transform);
+ declareOutputs(DeclaringAggregateTransform transform);
}

Powered by Google App Engine
@@ -2,27 +2,23 @@
/// by [transform].
///
- /// This works a little like [Transformer.apply], with two main differences.
- /// First, instead of having access to the primary input's contents, it only
- /// has access to its id. Second, instead of emitting [Asset]s, it just emits
- /// [AssetId]s through [transform.addOutputId].
+ /// This works a little like [AggregateTransformer.apply], with two main
+ /// differences. First, instead of having access to the primary inputs'
+ /// contents, it only has access to their ids. Second, instead of emitting
+ /// [Asset]s, it just emits [AssetId]s through [transform.addOutputId].
///
/// If this does asynchronous work, it should return a [Future] that completes
This is Rietveld 408576698